@@ -67,7 +67,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
@@ -459,5 +459,5 @@ int main(int argc,char* argv[]){
 
   }
  
-  return(0);
+  exit(0);
 }
