@@ -42,7 +42,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -64,7 +64,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"  the output format of integers and floating point numbers.\n");
       fprintf(stdout,"Options:                                                               \n");
       fprintf(stdout," -h  print this help message                                           \n");
-      return(0);
+      exit(0);
     }
   }
   /* END OF COMMAND LINE PROCESSING */
