@@ -69,7 +69,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -97,7 +97,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout," -r  number of bandwidths  (default 24)\n");
       fprintf(stdout," -s  print standard errors \n");
       fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
