@@ -1311,7 +1311,7 @@ int main(int argc, char * argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='v'){
       /*increase verbosity*/
@@ -1400,7 +1400,7 @@ int main(int argc, char * argv[]){
       fprintf(stdout," gbget 'file()<@x1+x2>'  print the sum of two subsequent columns\n");
       fprintf(stdout," gbget 'file(1:3){x2-2}'  select the first three columns in 'file' for the\n");
       fprintf(stdout,"                          rows whose second field is not lower then 2 \n");
-      return(0);
+      exit(0);
     }
     else if(opt=='F'){
       /*set the input fields separator string*/
