@@ -61,7 +61,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -78,7 +78,7 @@ int main(int argc,char* argv[]){
        fprintf(stdout,"Examples:\n");
        fprintf(stdout," gbgrid -c 1 -r 10 r+c  generates a vector with elements equal to the\n");
        fprintf(stdout,"                        sum of the row and column indexes\n");
-       return(0);
+       exit(0);
     }
     else if(opt=='v'){
       o_verbose=1;
