@@ -111,7 +111,8 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      2  the distribution function    \n");
       fprintf(stdout,"      3  the density function         \n");
       fprintf(stdout,"      4  transformed observations: uniform in [0.1] under the null\n");
-      fprintf(stdout,"      5  Renyi residuals: iid uniform in [0.1] under the null\n");
+      fprintf(stdout,"      5  log Renyi residuals: iid uniform in [0.1] under the null\n");
+      fprintf(stdout,"      6  Renyi residuals: iid exponential with mean 1 under the null\n");
       fprintf(stdout," -M  method used (default 0) \n");
       fprintf(stdout,"      0  unconditional, upper tail    \n");
       fprintf(stdout,"      1  threshold, upper tail        \n");
@@ -161,7 +162,7 @@ int main(int argc,char* argv[]){
     else if(opt=='O'){
       /* set the type of output */
       o_output = atoi(optarg);
-      if(o_output<0 || o_output>5){
+      if(o_output<0 || o_output>6){
 	fprintf(stderr,"ERROR (%s): output option '%d' not recognized. Try option -h.\n",
 		GB_PROGNAME,o_output);
 	exit(-1);
@@ -179,9 +180,9 @@ int main(int argc,char* argv[]){
      else if(opt=='M'){
       /* set the type of method */
       llparams.method = atoi(optarg);
-      if(o_output<0 || o_output>3){
+      if(llparams.method<0 || llparams.method>3){
 	fprintf(stderr,"ERROR (%s): method '%d' not recognized. Try option -h.\n",
-		GB_PROGNAME,o_output);
+		GB_PROGNAME,llparams.method);
 	exit(-1);
       }
     }
@@ -980,7 +981,7 @@ int main(int argc,char* argv[]){
 	     the density G(x)=1-exp(-x) to obtain independent
 	     variables uniformly distributed in [0,1]:
 
-	     {1-F(x[n-1])^N,1-(F(x[N-2])/F(x[N-1]))^{N-1},...,
+	     {1-F(x[N-1])^N,1-(F(x[N-2])/F(x[N-1]))^{N-1},...,
 	     1-(F(x[N-k])/F(x[N-k+1]))^{N-k+1} }
 
 
@@ -1064,6 +1065,104 @@ int main(int argc,char* argv[]){
       PRINTCOL(stdout,residual,llparams.used);
       free(residual);
       
+    }
+    break;
+  case 6: /* 
+	     from the order statistics x[0] < x[1] < x[2] < ... <
+	     x[N-1] we use a Renji transform to obtain variables which
+	     are independently uniformly distributed in [0,1].
+
+	     upper tail, k observations used
+	     ===============================
+
+	     x[N-k] < x[N-k+1] <... < x[N-1]
+
+	     consider
+	     
+	     {-ln F(x[N-1]),-ln F(x[N-2])+ln F(x[N-1]),...,-ln F(x[N-k])+ln F(x[N-k+1])}
+
+	     these are independent exponential variables with mean
+	     1/N,1/(N-1),..,1/(N-k+1). Thus consider
+
+	     {-N ln F(x[N-1]),(N-1) (-ln F(x[N-2])+ln F(x[N-1]) ),...,
+	     (N-k+1) (-ln F(x[N-k])+ln F(x[N-k+1]))}
+
+	     these are independent exponential r.v. with mean 1.
+
+
+	     lower tail, k observations used
+	     ===============================
+
+	     x[0] < x[1] < .... < x[k-1]
+
+	     consider
+	     
+	     {-ln (1-F(x[0])),-ln (1-F(x[1]))+ln (1-F(x[0]),...,-ln (1-F(x[k-1]))+ln (1-F(x[k-2]))}
+
+	     these are independent exponential variables with mean
+	     1/N,1/(N-1),..,1/(N-k+1). Thus consider
+
+	     {-N ln (1-F(x[0])),(N-1) (-ln (1-F(x[1]))+ln (1-F(x[0])),...,
+	     (N-k+1) (-ln (1-F(x[k-1]))+ln (1-F(x[k-2])))}
+
+	     these are independent exponential r.v. with mean 1.
+	  */
+    {
+      size_t i;
+      double * residual = (double *)  my_alloc(llparams.used*sizeof(double));
+
+      /* +++++++++++++++++++++++++++++++++++ */
+      if(o_verbose>=1){
+	for(i=0;i<xnum;i++)
+	  fprintf(stderr,EMPTY_SEP,xname[i]);
+	fprintf(stderr,EMPTY_NL,"min NLL/obs");
+	
+	for(i=0;i<xnum;i++)
+	  fprintf(stderr,FLOAT_SEP,x[i]);
+	fprintf(stderr,FLOAT_NL,llmin);
+      }
+      /* +++++++++++++++++++++++++++++++++++ */
+
+      switch(llparams.method){
+      case 0: 			/* upper tail */
+      case 1:
+	{
+
+	  const size_t indexmin= llparams.size-llparams.used;
+
+	  residual[llparams.used-1] = -( (double) llparams.size)*log(F(llparams.data[llparams.size-1],xnum,x));
+	  /* fprintf(stdout,FLOAT_NL,1-pow(F(llparams.data[llparams.size-1],xnum,x),llparams.size)); */
+	  for(i=0;i<llparams.used-1;i++){
+	    const double dtmp1 = F(llparams.data[indexmin+i],xnum,x);
+	    const double dtmp2 = F(llparams.data[indexmin+i+1],xnum,x);
+	    residual[i] = -((double) indexmin+i+1)*log(dtmp1/dtmp2);
+	    /* fprintf(stdout,FLOAT_NL,1-pow(dtmp1/dtmp2,i+1)); */
+	  }
+	}
+	break;
+
+      case 2: 			/* lower tail */
+      case 3:
+
+	{
+
+	  residual[0]=-( (double) llparams.size)*log(F(llparams.data[0],xnum,x));
+	  /* fprintf(stdout,FLOAT_NL,1-pow(1-F(llparams.data[0],xnum,x),llparams.size)); */
+	  for(i=1;i<llparams.used;i++){
+	    const double dtmp1 = 1-F(llparams.data[i],xnum,x);
+	    const double dtmp2 = 1-F(llparams.data[i-1],xnum,x);
+	    residual[i] = -((double) llparams.size-i)*log(dtmp1/dtmp2);
+	    /* fprintf(stdout,FLOAT_NL,1-pow(dtmp1/dtmp2,llparams.size-i)); */
+	  }
+
+	}
+	break;
+
+      }
+
+      PRINTCOL(stdout,residual,llparams.used);
+      free(residual);
+      
     }
     break;
   }
