@@ -243,7 +243,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"ERROR (%s): option %c not recognized\n",GB_PROGNAME,optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='F'){
       /*set the fields separator string*/
@@ -527,5 +527,5 @@ int main(int argc,char* argv[]){
   }
 
   
-  return(0);
+  exit(0);
 }
