@@ -229,7 +229,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
 	fprintf(stderr,"option %c not recognized\n",optopt);
-	return(-1);
+	exit(-1);
       }
       else if(opt=='k'){
 	/*the number of neighbors*/
@@ -342,10 +342,10 @@ int main(int argc,char* argv[]){
     }
     else{
       fprintf(stdout,"Kernel type not recognized. use -h\n");
-      return(-1);
+      exit(-1);
     }
 
 
-    return(0);
+    exit(0);
 
 }
