@@ -488,7 +488,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -519,7 +519,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      5  model definition               \n");
       fprintf(stdout," -F  input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help                      \n");
-      return(0);
+      exit(0);
     }
     else if(opt=='e'){
       /* set the minimization tolerance */
