@@ -807,7 +807,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -851,7 +851,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      algo  optimization methods: 0 Fletcher-Reeves, 1 Polak-Ribiere,  \n");
       fprintf(stdout,"            2 Broyden-Fletcher-Goldfarb-Shanno, 3 Steepest descent, 4 simplex,\n");
       fprintf(stdout,"            5 Broyden-Fletcher-Goldfarb-Shanno-2\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='M'){
       /* set the model */
