@@ -768,7 +768,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -834,7 +834,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      iter   maximum number of iterations   \n");
       fprintf(stdout,"      msize  max size, stopping criteria simplex dim. <max size    \n");
       fprintf(stdout,"             optimization method is simplex\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='t'){
       /* set the threshold */
