@@ -957,7 +957,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -995,7 +995,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout," -I  restart max iterations (default 2000, ignored with option -M 0)\n");
       fprintf(stdout," -F  input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help               \n");
-      return(0);
+      exit(0);
     }
     else if(opt=='e'){
       /* set the minimization tolerance */
