@@ -37,6 +37,7 @@ int main(int argc,char* argv[]){
   int o_table = 0;
   int o_verbose=0;
   int o_position=1;
+  int o_replace=0;
 
   /* variables for reading command line options */
   /* ------------------------------------------ */
@@ -44,7 +45,7 @@ int main(int argc,char* argv[]){
   /* ------------------------------------------ */
 
   /* COMMAND LINE PROCESSING */    
-  while((opt=getopt_long(argc,argv,"W:w:vhtx:q:en:F:",gb_long_options, &gb_option_index))!=EOF){
+  while((opt=getopt_long(argc,argv,"W:w:vhtx:q:en:F:Q",gb_long_options, &gb_option_index))!=EOF){
     if(opt==0){
       gbutils_header(argv[0],stdout);
       exit(0);
@@ -66,19 +67,26 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"each column. Without -t, columns are pooled unless -w is specified, in\n");
       fprintf(stdout,"which case all rows whose first element is inside the range are printed.\n");
       fprintf(stdout,"A different column for sorting can be specified with option -W. If 0 is\n");
-      fprintf(stdout,"specified, the cut is applied with respect to all columns\n");
+      fprintf(stdout,"specified, the cut is applied with respect to all columns. With option -Q\n");
+      fprintf(stdout,"each entry is replaced with the quantile range it belongs to, with respect\n");
+      fprintf(stdout,"to the distribution obtained from the entries in its column.\n");
       fprintf(stdout,"\nUsage: %s [options]\n\n",argv[0]);
       fprintf(stdout,"Options:\n");
       fprintf(stdout," -n  number of quantiles to print (default 10)\n");
       fprintf(stdout," -x  print the quantile (interpolated) associated with the value\n");
       fprintf(stdout," -q  print the value (interpolated) associated with the quantile\n");
       fprintf(stdout," -e  print the (asymptotic) error for -x or -q; doesn't work with -t\n");
+      fprintf(stdout," -Q  replace each element with the quantile range it belongs to\n");
       fprintf(stdout," -w  print observations inside a quantile windows\n");
       fprintf(stdout," -W  set the column to use (default 1)\n");
       fprintf(stdout," -t  consider separately each column of input\n");
       fprintf(stdout," -F  specify the input fields separators (default \" \\t\")\n");
       fprintf(stdout," -h  this help\n");
       fprintf(stdout," -v  verbose mode\n");
+      fprintf(stdout,"Examples:\n");
+      fprintf(stdout," gbquant -W 0 -w 0.1,0.9 < file  print the rows whose fields are all in\n");
+      fprintf(stdout,"                                 the center deciles.\n");
+      fprintf(stdout," gbquant -q 0.5 < file  print the median of the observations in 'file'.\n");
       exit(0);
     }
     else if(opt=='W'){
@@ -151,6 +159,10 @@ int main(int argc,char* argv[]){
       o_qval=1;
       free(stmp3);
     }
+    else if(opt=='Q'){
+      /* replace entries*/
+      o_replace=1;
+    }
     else if(opt=='e'){
       /*set the verbose mode*/
       o_err=1;
@@ -165,7 +177,11 @@ int main(int argc,char* argv[]){
   /* initialize global variables */
   initialize_program(argv[0]);
 
-  if(o_xval==0 && o_qval==0 && o_qwindow==0){/* print the list of quantiles */
+  /* set the actual number of points to consider: one less the number
+     of desired partition */
+  n=n-1;
+
+  if(o_xval==0 && o_qval==0 && o_qwindow==0 && o_replace==0){/* print the list of quantiles */
 
     if(!o_table){
       size_t size;
@@ -181,7 +197,7 @@ int main(int argc,char* argv[]){
 	fprintf(stderr,"loaded %zd data\n",size);
       /*+++++++++++++++++++++++++++++++++++++++*/
 	
-      if(n>size) n = size;/* for consistency */
+      if(n>=size) n = size-1;/* for consistency */
 
       /*+++++++++++++++++++++++++++++++++++++++*/
       if(o_verbose){ 
@@ -209,7 +225,7 @@ int main(int argc,char* argv[]){
 	fprintf(stderr,"loaded %zdx%zd data table\n",rows,columns);
       /*+++++++++++++++++++++++++++++++++++++++*/
 
-      if(n>rows) n = rows;/* for consistency */
+      if(n>=rows) n = rows-1;/* for consistency */
 
       /* allocate the array for the result */
       quantiles = (double **) my_alloc(n*sizeof(double*));
@@ -242,6 +258,120 @@ int main(int argc,char* argv[]){
       printmatrixbyrows(stdout,quantiles,n,columns);
     }
   }
+  else if(o_replace==1){/* replace values with their quantiles */
+
+    if(!o_table){
+      size_t size,tmpsize;
+      double *vals=NULL,*quantiles,*adtmp;
+      size_t i;
+
+      load(&vals,&size,0,splitstring);
+
+      /*+++++++++++++++++++++++++++++++++++++++*/
+      if(o_verbose)
+	fprintf(stderr,"loaded %zd data\n",size);
+      /*+++++++++++++++++++++++++++++++++++++++*/
+
+      /* duplicate the arrays */
+      adtmp = (double *)  my_alloc(size*sizeof(double));
+      memcpy(adtmp,vals,size*sizeof(double));
+      tmpsize = size;
+      denan(&adtmp,&tmpsize);
+      qsort(adtmp,tmpsize,sizeof(double),sort_by_value);
+
+      if(n>=tmpsize) n = tmpsize-1;/* for consistency */
+
+      /* allocate the array for the quantiles */
+      quantiles = (double *) my_alloc(n*sizeof(double*));
+
+      /* compute the quntiles */
+      for(i=1;i<=n;i++){
+	double dtmp1 = i/(n+1.);
+	int index = floor((tmpsize+1.)*dtmp1);
+	double delta = (tmpsize+1.)*dtmp1-index;
+	quantiles[i-1]= adtmp[index-1]*(1.-delta)+adtmp[index]*delta;
+      }
+
+      /* free temporary duplication */
+      free(adtmp);
+
+      /* compute and print the result */
+      for(i=0;i<size;i++){
+	double dtmp1=vals[i];
+	if(finite(dtmp1)){
+	  size_t h;
+	  for(h=0;h<n;h++){
+	    if(quantiles[h] > dtmp1) break;
+	  }
+	  printf(INT_NL, h+1);
+	}
+	else{
+	  printf(FLOAT_NL,dtmp1);
+	}
+      }
+
+    }
+    else{
+      size_t rows=0,columns=0,i,j;
+      double **vals=NULL;
+      double **quantiles;
+    
+      loadtable(&vals,&rows,&columns,0,splitstring);
+    
+      /*+++++++++++++++++++++++++++++++++++++++*/
+      if(o_verbose)
+	fprintf(stderr,"loaded %zdx%zd data table\n",rows,columns);
+      /*+++++++++++++++++++++++++++++++++++++++*/
+
+      if(n>=rows) n = rows-1;/* for consistency */
+      
+      /* allocate the array for the quantiles */
+      quantiles = (double **) my_alloc(n*sizeof(double*));
+      for(i=0;i<n;i++)
+	quantiles[i] = (double *) my_alloc(columns*sizeof(double));
+      
+      /* compute the quantiles */
+      for(i=0;i<columns;i++){
+	size_t size=rows;
+	
+	/* duplicate the arrays */
+	double *adtmp = (double *)  my_alloc(rows*sizeof(double*));
+	memcpy(adtmp,vals[i],rows*sizeof(double*));      
+	
+	denan(&adtmp,&size);
+	qsort(adtmp,size,sizeof(double),sort_by_value);
+	for(j=1;j<=n;j++){
+	  double dtmp1 = j/(n+1.);
+	  int index = floor((size+1.)*dtmp1);
+	  double delta = (size+1.)*dtmp1-index;
+	  
+	  if(dtmp1<1./(size+1.)) quantiles[j-1][i]=adtmp[0];
+	  else if (dtmp1>1.-1./(size+1.)) quantiles[j-1][i]=adtmp[size-1];	  
+	  else quantiles[j-1][i]=adtmp[index-1]*(1.-delta)+adtmp[index]*delta;
+	}
+	free(adtmp);
+      }
+      
+      /* compute and print the result */
+      for(i=0;i<rows;i++){
+	for(j=0;j<columns;j++){
+	  double dtmp1=vals[j][i];
+	  if(finite(dtmp1)){
+	    size_t h;
+	    for(h=0;h<n;h++){
+	      if(quantiles[h][j] > dtmp1) break;
+	    }
+	    printf(INT_SEP, h+1);
+	  }
+	  else{
+	    printf(FLOAT_SEP,dtmp1);
+	  }
+	}
+	printf("\n");
+      }
+    }
+
+  }
   else if(o_qwindow==1){ /* print the data inside the quantile windows */
     if(!o_table){
       size_t rows=0,columns=0,i,j;
