@@ -72,14 +72,14 @@ int main(int argc,char* argv[]){
   char o_median=0;
   char o_mode=0;
   char o_central=0;
-  double result[10];
+  double result[11];
   double variance;
 
   char *splitstring = strdup(" \t");
 
   /* options options */
-  char * const output_opts[] = {"mean","std","skew","kurt","adev","min","max","num","median","mode",NULL};
-  char * const output_description[] = {"mean","stdev","skewness","kurtosis","average dev.","min","max","valid","median","mode",NULL};
+  char * const output_opts[] = {"mean","std","skew","kurt","adev","min","max","num","median","mode","var",NULL};
+  char * const output_description[] = {"mean","stdev","skewness","kurtosis","average dev.","min","max","valid","median","mode","variance",NULL};
   size_t outnum;
   size_t *outtype;
 
@@ -124,13 +124,13 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"separately. A header line is added with the meaning of the different columns.\n");
       fprintf(stdout,"The mode is computed using the Half-Sample method.\n");
       fprintf(stdout,"\nUsage: %s [options]\n\n",argv[0]);
-      fprintf(stdout,"Options:                                                             \n");
-      fprintf(stdout," -m  add the sample median to the estimated statistics               \n");
-      fprintf(stdout," -t  print statistics for each column of input                       \n");
-      fprintf(stdout," -s  short: mean std skew kurt adev min max (median) num             \n");
-      fprintf(stdout," -O  select output: mean,std,skew,kurt,adev,min,max,median,num,mode  \n");
-      fprintf(stdout," -o  set the output format (default '%%12.6e')  \n");
-      fprintf(stdout," -F  specify the input fields separators (default \" \\t\")          \n");
+      fprintf(stdout,"Options:                                                                 \n");
+      fprintf(stdout," -m  add the sample median to the estimated statistics                   \n");
+      fprintf(stdout," -t  print statistics for each column of input                           \n");
+      fprintf(stdout," -s  short: mean std skew kurt adev min max (median) num                 \n");
+      fprintf(stdout," -O  select output: mean,std,var, skew,kurt,adev,min,max,median,num,mode \n");
+      fprintf(stdout," -o  set the output format (default '%%12.6e')                           \n");
+      fprintf(stdout," -F  specify the input fields separators (default \" \\t\")              \n");
       fprintf(stdout," -h this help\n");
       fprintf(stdout,"Examples:\n");
       fprintf(stdout," gbstat -O median,kurt < file  compute the median and the kurtosis\n");
@@ -202,7 +202,7 @@ int main(int argc,char* argv[]){
 	o_median=1;
       else if (outtype[i]==9)
 	o_mode=1;
-      else if  (outtype[i]<7)
+      else if  (outtype[i]<7 || outtype[i]==10)
 	o_central=1;
   }
 
@@ -217,7 +217,7 @@ int main(int argc,char* argv[]){
     result[7]=size;
     if(o_central)
       moment(vals,size,
-	     &(result[0]),&(result[4]),&(result[1]),&variance,&(result[2]),&(result[3]),&(result[5]),&(result[6]));
+	     &(result[0]),&(result[4]),&(result[1]),&(result[10]),&(result[2]),&(result[3]),&(result[5]),&(result[6]));
     
     /* sort the data */
     if(o_median || o_mode)
@@ -279,7 +279,7 @@ int main(int argc,char* argv[]){
       result[7]=itmp1;
       if(o_central)
 	moment(vals[i],itmp1,
-	       &(result[0]),&(result[4]),&(result[1]),&variance,&(result[2]),&(result[3]),&(result[5]),&(result[6]));
+	       &(result[0]),&(result[4]),&(result[1]),&(result[10]),&(result[2]),&(result[3]),&(result[5]),&(result[6]));
 
       /* sort the data */
       if(o_median || o_mode)
