@@ -352,7 +352,7 @@ double TRRT_pscore(const double statistic,  const size_t size){
 }
 
 
-double Dplus_test(double * data, const size_t size)
+double Dminus_test(double * data, const size_t size)
 {
 
   size_t i;
@@ -378,7 +378,7 @@ double Dplus_test(double * data, const size_t size)
     
 }
 
-double Dplus_pscore(const double statistic,  const size_t size)
+double Dminus_pscore(const double statistic,  const size_t size)
 {
   const size_t maxindex = (size_t) floor(size*(1-statistic));
   const double N = (double) size;
@@ -410,20 +410,20 @@ double Dplus_pscore(const double statistic,  const size_t size)
     fprintf(stderr,"#  Sample size                         %zd\n",size);
     fprintf(stderr,"#  Standardized score                  %g\n",stat);
     fprintf(stderr,"#  Exact inference:\n");
-    fprintf(stderr,"#   One-sided P-value: Pr{stat>D+}      %g\n",1-G);
-    fprintf(stderr,"#   One-sided P-value: Pr{stat<D+}      %g\n",G);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>D-}      %g\n",1-G);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<D-}      %g\n",G);
     fprintf(stderr,"#  Asymptotic inference:\n");
-    fprintf(stderr,"#   One-sided P-value: Pr{stat>D+}      %g\n",1-Gasy);
-    fprintf(stderr,"#   One-sided P-value: Pr{stat<D+}      %g\n",Gasy);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>D-}      %g\n",1-Gasy);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<D-}      %g\n",Gasy);
   }
   /* +++++++++++++++++++++++++++++++++++++ */
 
-  return G;
+  return 1-G;
     
 }
 
 
-double Dminus_test(double * data, const size_t size)
+double Dplus_test(double * data, const size_t size)
 {
 
   size_t i;
@@ -450,7 +450,7 @@ double Dminus_test(double * data, const size_t size)
 }
 
 
-double Dminus_pscore(const double statistic,  const size_t size)
+double Dplus_pscore(const double statistic,  const size_t size)
 {
   const size_t maxindex = (size_t) floor(size*(1-statistic));
   const double N = (double) size;
@@ -482,15 +482,15 @@ double Dminus_pscore(const double statistic,  const size_t size)
     fprintf(stderr,"#  Sample size                         %zd\n",size);
     fprintf(stderr,"#  Standardized score                  %g\n",stat);
     fprintf(stderr,"#  Exact inference:\n");
-    fprintf(stderr,"#   One-sided P-value: Pr{stat>D-}      %g\n",1-G);
-    fprintf(stderr,"#   One-sided P-value: Pr{stat<D-}      %g\n",G);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>D+}      %g\n",1-G);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<D+}      %g\n",G);
     fprintf(stderr,"#  Asymptotic inference:\n");
-    fprintf(stderr,"#   One-sided P-value: Pr{stat>D-}      %g\n",1-Gasy);
-    fprintf(stderr,"#   One-sided P-value: Pr{stat<D-}      %g\n",Gasy);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>D+}      %g\n",1-Gasy);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<D+}      %g\n",Gasy);
   }
   /* +++++++++++++++++++++++++++++++++++++ */
 
-  return G;
+  return 1-G;
     
 }
 
@@ -499,7 +499,7 @@ double D_test(double * data, const size_t size)
 {
 
   size_t i;
-  double result=0;
+  double result=0,dtmp1=0;
 
   /* sort data if needed */
   if(Is_Data_Sorted==0)
@@ -512,10 +512,11 @@ double D_test(double * data, const size_t size)
   }
   else{
     for(i=0;i<size;i++){
-      const double dtmp1 = data[i] - (double) i/size ;
-      const double dtmp2 = (double) (i+1)/ (double) size - data[i];
-      if(dtmp1>dtmp2 && dtmp1>result) result = dtmp1;
-      else if(dtmp2>result) result = dtmp2;
+      const double dtmp2 = (double) (i+1)/ (double) size;
+      const double dtmp3 = data[i];
+      const double dtmp4 = fabs(dtmp2-dtmp3)>fabs(dtmp1-dtmp3) ? fabs(dtmp2-dtmp3) : fabs(dtmp1-dtmp3);
+      if(dtmp4>result) result = dtmp4;
+      dtmp1=dtmp2;
     }
   }
  
@@ -610,6 +611,66 @@ double V_test(double * data, const size_t size)
     
 }
 
+double Qkp(double x){
+
+  double sum=0.0;
+  
+  /* computation of Qkp(x) according to numerical recipes */
+  if(x<0.4){
+    sum=0.5;
+  }
+  else{
+    const double x2 = 2.0*x*x;
+    double const eps1=10*DBL_EPSILON;
+    double const eps2=DBL_EPSILON;
+    
+    int i=1;
+    double term=0.0,oldterm=0.0;
+    
+    do{
+      oldterm=term;    /* save previous term */
+      term=(2*x2*i*i-1)*exp(-x2*i*i);  /* new term */
+      sum += term;          /* terms sum */
+      i++;
+    }
+    while(fabs(term) > eps1*fabs(oldterm) && fabs(term) > eps2*fabs(sum));
+  }
+  
+  return 2*sum;
+
+}
+
+double V_pscore(const double statistic,  const size_t size)
+{
+
+  const double eff_size =sqrt(size);
+  const double stat = (eff_size+0.155+0.24/eff_size)*statistic ; 
+  const double statasy = eff_size*statistic ;
+  const double qkp = Qkp(stat);
+  const double qkpasy = Qkp(statasy);
+
+  /* +++++++++++++++++++++++++++++++++++++ */
+  if(O_Verbose>1){
+    fprintf(stderr,"#  Observed V                          %g\n",statistic);
+    fprintf(stderr,"#  Sample size                         %zd\n",size);
+    fprintf(stderr,"#  Asymptotic standardized score       %g\n",statasy);
+    fprintf(stderr,"#  Small-sample corrected score        %g\n",stat);
+    fprintf(stderr,"#  Small-sample corrected inference:\n");
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>V}      %g\n",qkp);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<V}      %g\n",1-qkp);
+    fprintf(stderr,"#  Asymptotic inference:\n");
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>V}      %g\n",qkpasy);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat<V}      %g\n",1-qkpasy);
+  }
+  /* +++++++++++++++++++++++++++++++++++++ */
+
+  
+  return qkp;
+
+}
+
+
+
 
 double W2_test(double * data, const size_t size)
 {
@@ -1168,7 +1229,7 @@ double CHI2_2_pscore(const double statistic, const size_t size)
     fprintf(stderr,"#  Observed T                          %g\n",statistic);
     fprintf(stderr,"#  Degrees of freedom                  %zd\n",size-1);
     fprintf(stderr,"#  Asymptotic inference:\n");
-    fprintf(stderr,"#   Two-sided P-value: Pr{stat>T}      %g\n",
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>T}      %g\n",
 	     gsl_cdf_chisq_Q (statistic,size-1));
 
   }
@@ -1759,36 +1820,20 @@ double KS_pscore(const double statistic,
 
   const double eff_size =sqrt(((double) size1*size2)/( (double) size1+size2));
   const double x = (eff_size+0.12+0.11/eff_size)*statistic ; 
-
-  /* computation of Qks(x) */
-  const double x2 = -2.0*x*x;
-  double const eps1=10*DBL_EPSILON;
-  double const eps2=DBL_EPSILON;
+  const double qks=Qks(x);
   
-  int i=1;
-  double fac=2.0,sum=0.0,term=0.0,absterm=0.0;
-
-  do{
-    absterm=fabs(term);    /* previous term absolute value */
-    term=fac*exp(x2*i*i);  /* new term */
-    sum += term;           /* terms sum */
-    fac = -fac;            /* change sign of the next term */
-    i++;
-  }
-  while(fabs(term) > eps1*absterm && fabs(term) > eps2*sum);
-
 
   /* +++++++++++++++++++++++++++++++++++++ */
   if(O_Verbose>1){
     fprintf(stderr,"#  Observed KS                          %g\n",statistic);
     fprintf(stderr,"#  Effective Size                       %g\n",eff_size*eff_size);
     fprintf(stderr,"#  Asymptotic inference:\n");
-    fprintf(stderr,"#   Two-sided P-value: Pr{stat>KS}      %g\n",sum);
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>KS}      %g\n",qks);
   }
   /* +++++++++++++++++++++++++++++++++++++ */
 
   
-  return sum;
+  return qks;
 
 }
 
@@ -1844,7 +1889,7 @@ double CHI2_N_pscore(const double statistic,
     fprintf(stderr,"#  Observed T                          %g\n",statistic);
     fprintf(stderr,"#  Degrees of freedom                  %zd\n",(smpls-1)*(length[0]-1));
     fprintf(stderr,"#  Asymptotic inference:\n");
-    fprintf(stderr,"#   Two-sided P-value: Pr{stat>T}      %g\n",
+    fprintf(stderr,"#   One-sided P-value: Pr{stat>T}      %g\n",
 	     gsl_cdf_chisq_Q (statistic,(smpls-1)*(length[0]-1)) );
 
   }
@@ -2397,7 +2442,8 @@ int main(int argc,char* argv[]){
       /*print help*/
       fprintf(stdout,"Compute statistical tests on data. Each test is specified by a unique\n");
       fprintf(stdout,"name and optional parameters follows, separated by commas. Depending\n");
-      fprintf(stdout,"on the test, one, two or three columns of data are expected. '1 sample'\n");
+      fprintf(stdout,"on the test, one, two or three columns of data are expected. '1 dist'\n");
+      fprintf(stdout,"tests expect data in [0,1] from a distribution function. '1 sample'\n");
       fprintf(stdout,"tests expect a single columns. Test on 'pairs' expect two columns of\n");
       fprintf(stdout,"equal length. Test on '2 samples' expect two columns of data, possibly\n");
       fprintf(stdout,"of different length. Test on 2+ and 3+ samples expect a varying number of\n");
@@ -2409,8 +2455,8 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"and is performed consistently with the nature of the test.\n");
       fprintf(stdout,"\nUsage: %s [options] <tests list> \n\n",argv[0]);
       fprintf(stdout,"Tests typically assume 1, 2 or 3+ samples. Available tests are:\n\n");
-      fprintf(stdout," D+,D-,D,V 1 samp   Kolmogorov-Smirnov tests on cumulated data \n");
-      fprintf(stdout," W2,A2,U2  1 samp   Cramer-von Mises tests on cumulated data   \n");
+      fprintf(stdout," D+,D-,D,V 1 dist   Kolmogorov-Smirnov tests on cumulated data \n");
+      fprintf(stdout," W2,A2,U2  1 dist   Cramer-von Mises tests on cumulated data   \n");
       fprintf(stdout," CHI2-1    1 samp   Chi-Sqrd, 1 samp. 2nd column: th. prob.    \n");
       fprintf(stdout," WILCO     1 samp   Wilcoxon signed-rank test (mode=0)         \n");
       fprintf(stdout," TS        1 samp   Student's T (mean=0)                       \n");
@@ -2544,7 +2590,7 @@ int main(int argc,char* argv[]){
     else if(NAME("V"))
       {
 
-	run_onesample("V Kuiper Test",V_test,NULL,data,length,columns);
+	run_onesample("V Kuiper Test",V_test,V_pscore,data,length,columns);
       }
     else if(NAME("W2"))
       {
