@@ -46,7 +46,7 @@ int main(int argc,char* argv[]){
     }
     else if(opt=='?'){
       fprintf(stderr,"option %c not recognized\n",optopt);
-      return(-1);
+      exit(-1);
     }
     else if(opt=='h'){
       /*print help*/
@@ -67,7 +67,7 @@ int main(int argc,char* argv[]){
       fprintf(stdout,"      1  covariance/correlation without mean removal            \n");
       fprintf(stdout," -F specify the input fields separators (default \" \\t\")      \n");
       fprintf(stdout," -h this help\n");
-      return(0);
+      exit(0);
     }
     else if(opt=='M'){
       /*set the method to use*/
@@ -149,5 +149,5 @@ int main(int argc,char* argv[]){
   }
 
 
-  return(0);
+  exit(0);
 }
